@@ -249,6 +249,7 @@ class ROCv3():
         return param_reg_pairs
 
     def _cache(self, changed_registers: list) -> list:
+        dict_write_registers = {}
         write_registers = []
         for reg in changed_registers:
             key = (reg[0], reg[1])
@@ -257,10 +258,13 @@ class ROCv3():
             new_val = (cached_val & (~reg[3])) | reg[2]
             if new_val != cached_val:
                 self.transaction_logger.debug("Cache miss")
-                write_registers.append((reg[0], reg[1], new_val))
+                dict_write_registers[(reg[0], reg[1])] = new_val
                 self.cache[key] = new_val
             else:
                 self.transaction_logger.debug("Cache hit")
+
+        if dict_write_registers:
+            write_registers = [(*key, value) for key, value in dict_write_registers.items()]
         return write_registers
 
     def configure(self, configuration: dict, readback=False):
